#
# spec file for package xf86-video-vmware
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-video-vmware
VCS: https://src.suse.de/SLFO-pool/xf86-video-vmware#cc09023232b4351a3a9113df37b0d9253601201c4ac6873aad4905217cca7145
Version:        13.4.0
Release:        160000.1.10
Summary:        VMware SVGA video driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            http://xorg.freedesktop.org/
#http://xorg.freedesktop.org/releases/individual/driver/
# Source url disabled, we are using a git checkout via source service
#Source0:        http://xorg.freedesktop.org/releases/individual/driver/%%{name}-%%{version}.tar.bz2
Source0:        %{name}-%{version}.tar.xz
ExclusiveArch:  %ix86 x86_64
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(fontsproto)
BuildRequires:  pkgconfig(pciaccess) >= 0.8.0
BuildRequires:  pkgconfig(randrproto)
BuildRequires:  pkgconfig(renderproto)
BuildRequires:  pkgconfig(videoproto)
BuildRequires:  pkgconfig(xatracker) >= 0.4.0
BuildRequires:  pkgconfig(xextproto)
BuildRequires:  pkgconfig(xineramaproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.0.1
BuildRequires:  pkgconfig(xproto)
Supplements:    modalias(xorg-x11-server:pci:v000015ADd*sv*sd*bc03sc*i*)
# This was part of the xorg-x11-driver-video package up to version 7.6
Conflicts:      xorg-x11-driver-video <= 7.6
%x11_abi_videodrv_req

%description
vmware is an Xorg driver for VMware virtual video cards.

%prep
%autosetup -p1

%build
# We have some -z now related errors during X default startup (boo#1197994):
# this is directly visible on startup, so easy to test later on.
export SUSE_ZNOW=0
NOCONFIGURE=1 autoreconf -fi
%configure
%make_build

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%files
%license COPYING
%doc README
%dir %{_libdir}/xorg/modules/drivers
%{_libdir}/xorg/modules/drivers/vmware_drv.so
%{_datadir}/man/man4/vmware.4%{?ext_man}

%changelog
* Mon Feb  6 2023 sndirsch@suse.com
- Update to version 13.4.0
- supersedes u_Fix-build-gcc-12.patch
- switched back to tarball from git checkout via source service
* Sat May 14 2022 sndirsch@suse.com
- set SUSE_ZNOW to 0 (boo#1197994)
* Wed Feb 23 2022 bjorn.lie@gmail.com
- Update to version 13.3.0+12:
  * vmwgfx:
  - Change header inclusion order to avoid xorg headers catching
    stdbool.h
  - Unify style in scanout_update and present functions
  - Limit the number of cliprects in a drm present_readback
    command v3
  - Limit the number of cliprects in a drm present command v3
  - Limit the number of cliprects in a drm dirtyfb command v3
  - Don't exceed the device command size limit v3
  - Fix invalid memory accesses in CloseScreen
  - Use libdrm to obtain the drm device node name v2
  - Fix a memory leak
  - Fix XVideo memory leaks
  * saa: Make sure damage destruction happens at the correct
    location
  * Remove obsolete B16 & B32 tags in struct definitions
- Switch to git checkout via source service.
- Add u_Fix-build-gcc-12.patch: Still needs a patch to build with
  gcc 12.
- Modernize spec, add libtool BuildRequires and bootstrap build.
* Sat May 19 2018 sndirsch@suse.com
- Update to version 13.3.0
  * This release provides dri3 support for recent mesa (XA version
    2.4+), build support for xserver 1.20, a number of compilation
    warning fixes, removal of old Xwayland and Xmir support, and a
    couple of minor bug fixes.
  * Note that linux distros that choose to not compile in kernel
    modesetting- and 3D should avoid enabling the vmwgfx linux
    kernel module.
  * As usual, the release is intended to be usable even with old
    X servers, but testing for older servers (xserver 1.0+) has
    been limited to compile-testing only. Dedicated functionality
    testing has been run on xserver 1.19.99 series.
* Tue May 30 2017 sndirsch@suse.com
- includes everything needed for missing sle issue entries:
  fate #315643-315645, 319159-319161, 319618 (bsc#1041651)
* Sat Nov 19 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 13.2.1:
  This release provides support for adapting to a desktop configuration (read
  VMware GUI configuration) exposed using drm connectors rather than using
  RandR12+. Since this is the way gnome-shell/Wayland adapts to a desktop
  configuration this driver can coexist with an auto-fit multimonitor VMware
  gnome-shell/Wayland configuration and therefore enables future open-vm-tools
  versions to expose GUI configuration changes through drm connectors at system
  start-up time without using the xorg driver as a proxy.
  It also contains a compilation fix for ABI 23 (Xserver 1.19).
* Fri Jan 23 2015 sfalken@opensuse.org
- Update to version 13.1.0:
  + Adapt to GC client clip changes in server 1.17
  + Fix xf86xv.h cannot be included without first including
    xorg-server.h
  + Fix saa_check_poly_fill_rect_noreadback v2
  + Fix saa_check_copy_window dirty region v3
  + Revert "vmware/saa: Disable the noreadback polyfillrect
    optimization"
  + Fix cursor problem with multimon
  + Don't add puixmaps to the pixmap list if they're already
    on it.
  + Fix overlay related compile breakage on earlier X servers
  + Fix bootstrap related compile errors on earlier X servers
  + Clear the PITCHLOCK register if available before modeset
  + Fix out of bound array indexing
  + Fix compilation issue on older X servers
  + Fix uninitialized values in video commands
  + Fix an error path segfault (fdo#80645)
  + Fix auto colorkey fill usage
  + Better error logging when handling cursors
  + Don't move cursors without images
  + Fix xwayland build on newer XA versions
  + Add support for server managed fds
  + Add support for XSERVER_PLATFORM_BUS
  + Fix initial dirty region for pixmaps
  + Set desired modes after xMir screen init
  + Don't tell XA that we have a mask when we haven't
  + Don't change backing-store of active scanout services
  + Fix build without xatracker
- Changes from version 13.0.1
  + Fix compilation on newer X servers
  + Always allocate shared hardware surfaces
  + Require libdrm 2.4.38 to build XMir
  + Block DMA to prime surfaces for now
  + Enable direct dmas
  + Add support for XWayland
  + Add support for XMir v2
  + Add an infrastructure to be able to run hosted under
    a compositor v2
  + Fix compile breakage on XA version 1
  + Really allow XA version 2
  + Revert "vmwgfx: Get rid of device-specific DMA code"
  + Support also XA version 1 v2
  + Handle changes of DamageUnregister API in 1.14.99.2
  + Implement textured video completely on top of XA
  + Avoid HW operations when not master
  + Update for XA API changes
  + Dropped (patches accepted upstream):
  + U_vmware-vmwgfx-Don-t-add-pixmaps-to-the-pixmap-list-i.patch
  + u_xf86xv.h-cannot-be-included-without-first-including-.patch
  + xf86-video-vmware-13.0.2.tar.bz2
* Tue Oct 14 2014 sndirsch@suse.com
- U_vmware-vmwgfx-Don-t-add-pixmaps-to-the-pixmap-list-i.patch
  * prevent endless looping during Xserver reset (bnc#900884)
* Mon Oct  6 2014 sndirsch@suse.com
- u_xf86xv.h-cannot-be-included-without-first-including-.patch
  * include xorg-server.h before xf86xv.h in order to fix
    build with latest glibc
* Wed May  7 2014 sndirsch@suse.com
- update to release 13.0.2
  * This release contains support for both XMir and XWayland,
    updated support for the new XA version released with the
    new Mesa 10.1 version.
* Wed Mar 19 2014 sndirsch@suse.com
- update to current git commit 51cdfa6 in order to fix build against
  latest xserver
- obsoletes U_0001-vmwgfx-update-for-XA-API-changes.patch,
  U_0002-vmwgfx-Avoid-HW-operations-when-not-master.patch,
  U_0003-vmwgfx-Implement-textured-video-completely-on-top-of.patch,
  U_0004-vmwgfx-Get-rid-of-device-specific-DMA-code.patch,
  U_0005-vmwgfx-handle-changes-of-DamageUnregister-API-in-1.1.patch
* Mon Dec  2 2013 sndirsch@suse.com
- U_0001-vmwgfx-update-for-XA-API-changes.patch
- U_0002-vmwgfx-Avoid-HW-operations-when-not-master.patch
  * Note that for DRI2, a dri2_copy_region becomes a NOP when not master.
    Additionally, all dri2 operations that lead to a potential kernel
    access will return FALSE.
- U_0003-vmwgfx-Implement-textured-video-completely-on-top-of.patch
  * Remove device-specific hacks. This may increase resource usage a little
    on old hardware revisions, but we don't need separate code paths on
    different hardware revisions.
- U_0004-vmwgfx-Get-rid-of-device-specific-DMA-code.patch
  * It's rarely used and things seem to work well enough on top of XA.
- U_0005-vmwgfx-handle-changes-of-DamageUnregister-API-in-1.1.patch
  * Fix is inspired from the intel driver.
* Tue May  7 2013 sndirsch@suse.com
- xf86-video-vmware 13.0.1
  * vmwgfx: Use myGlyphs to fix crashes (fdo#61780)
  * Kill mibstore
- obsoletes U_mibstore.patch
* Fri Apr  5 2013 idonmez@suse.com
- Add Source URL, see https://en.opensuse.org/SourceUrls
* Wed Mar 20 2013 sndirsch@suse.com
- make supplements conditional on hardware (bnc#810333)
* Tue Mar 19 2013 hrvoje.senjan@gmail.com
- Add U_mibstore.patch, fixes build with xorg-server 1.14
* Thu Jan 24 2013 sndirsch@suse.com
- xf86-video-vmware 13.0.0
  * Release for Xserver 1.13. ABI bump plus bug fixes. A must have
    for all users of the Xserver 1.13.
* Mon Sep 17 2012 sndirsch@suse.com
- update to latest git commit 007bed3
* Mon Jul 30 2012 dmueller@suse.com
- disable build on anything other than i386/x86_64
* Sat Jun 30 2012 dimstar@opensuse.org
- Add pkgconfig(xatracker) BuildRequires for full 3D support.
  (bnc#729189).
* Thu Apr 19 2012 dimstar@opensuse.org
- Update to version 12.0.2:
  + Adapt to X 1.12 API
- Use %%x11_abi_videodrv_req instead of static ABI requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-video-vmware from xorg-x11-driver-video.
  Initial version: 11.0.3.
